@@ -190,26 +190,37 @@ sub _format_verbatim {
     return $pre . ( @c ? ("\n\n" . _format_chunk($Quiki, join("\n", @c))) : "");
 }
 
+our %SAVES;
+our $SAVES;
+
 sub _inlines {
     my ($Quiki, $chunk) = @_;
 
     my $script = $Quiki->{SCRIPT_NAME};
 
+    sub _saveit {
+        my $text = shift;
+        $SAVES++;
+        $SAVES{"#$SAVES"} = $text;
+        return "#$SAVES";
+    }
+    sub _loadit { $SAVES{$_[0]} }
+
     my @inline =
       (
        ## [[http://foo]] -- same as http://foo ?
-       qr/\[\[(\w+:\/\/[^\]|]+)\]\]/            => sub { a({-href=>$1}, $1) },
+       qr/\[\[(\w+:\/\/[^\]|]+)\]\]/            => sub { _saveit(a({-href=>$1}, $1)) },
        ## [[nodo]]
        qr/\[\[([^\]|]+)\]\]/                    => sub {
-           a({-href=>"$script?node=".uri_escape($1) }, $1)
+           _saveit(a({-href=>"$script?node=".uri_escape($1) }, $1))
        },
        ## [[protocol://foo|descricao]]
        qr/\[\[(\w+:\/\/[^\]|]+)\|([^\]|]+)\]\]/ => sub {
-           a({-href=>$1}, _inlines($Quiki, $2))
+           _saveit(a({-href=>$1}, _inlines($Quiki, $2)))
        },
        ## [[nodo|descricao]]
        qr/\[\[([^\]|]+)\|([^\]|]+)\]\]/         => sub {
-           a({-href=>"$script?node=".uri_escape($1) }, _inlines($Quiki, $2))
+           _saveit(a({-href=>"$script?node=".uri_escape($1) }, _inlines($Quiki, $2)))
        },
 
        ## ** foo **
@@ -253,6 +264,9 @@ sub _inlines {
        ## urls que nao sigam aspas
        qr/(?<!")$RE{URI}{-keep}/                => sub { a({-href=>$1}, $1) },
 
+       ## savits
+       qr/(\#\d+)/              => sub { _loadit($1) },
+
       );
 
     while (@inline) {
